@@ -432,9 +432,8 @@ OSLToyMainWindow::OSLToyMainWindow(OSLToyRenderer* rend, int xr, int yr)
     QPixmap pixmap(xres, yres);
     OIIO::ImageBuf checks(
         OIIO::ImageSpec(xres, yres, 3, OIIO::TypeDesc::UINT8));
-    const float white[] = { 1, 1, 1 };
-    const float black[] = { 0, 0, 0 };
-    OIIO::ImageBufAlgo::checker(checks, 16, 16, 1, white, black);
+    OIIO::ImageBufAlgo::checker(checks, 16, 16, 1, 1.0f /* white */,
+                                0.0f /* black */);
     renderView->update(checks);
 
     textTabs = new QTabWidget;
@@ -1052,14 +1051,14 @@ OSLToyMainWindow::make_param_adjustment_row(ParamRec* param,
             auto label_and_adjust_layout = new QHBoxLayout;
             label_and_adjust->setLayout(label_and_adjust_layout);
             std::string labeltext;
-            if (param->type == TypeDesc::TypeColor)
+            if (param->type == TypeColor)
                 labeltext = string_view(&("RGB"[c]), 1);
             else
                 labeltext = string_view(&("xyz"[c]), 1);
             auto channellabel = QtUtils::make_qlabelfmt("{}", labeltext);
             label_and_adjust_layout->addWidget(channellabel);
             auto adjustWidget = new QtUtils::DoubleSpinBox(param->fdefault[c]);
-            if (param->type == TypeDesc::TypeColor) {
+            if (param->type == TypeColor) {
                 adjustWidget->setRange(0.0, 1.0);
             }
             label_and_adjust_layout->addWidget(adjustWidget);
